import os


class InvalidPathException(Exception):

    def __init__(self, path):
        self.path = path


def generate_path_iter(*args, **kwargs):
    recursive = kwargs.get('recursive', False)
    for path in args:
        if os.path.isfile(path):
            yield path
        elif os.path.isdir(path):
            if not recursive:
                raise InvalidPathException(path)
            for root, _, file_paths in os.walk(path):
                for file_path in file_paths:
                    yield os.path.join(root, file_path)
        else:
            raise InvalidPathException(path)
